@@ -1,10 +1,13 @@
+-- support for i18n
+local S = armor_i18n.gettext
+
 if not minetest.global_exists("sfinv") then
-	minetest.log("warning", "3d_armor_sfinv: Mod loaded but unused.")
+	minetest.log("warning", S("3d_armor_sfinv: Mod loaded but unused."))
 	return
 end
 
 sfinv.register_page("3d_armor:armor", {
-	title = "Armor",
+	title = S("Armor"),
 	get = function(self, player, context)
 		local name = player:get_player_name()
 		local formspec = armor:get_armor_formspec(name, true)
